Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

Here is a list of all namespace members with links to the namespace documentation for each member:

### - t -

- tail() : stan::math
- tan() : stan::math
- tanh() : stan::math
- tcrossprod() : stan::math
- tgamma() : stan::math
- to_array_1d() : stan::math
- to_array_2d() : stan::math
- to_fvar() : stan::math
- to_matrix() : stan::math
- to_row_vector() : stan::math
- to_var() : stan::math
- to_vector() : stan::math
- trace() : stan::math
- trace_gen_inv_quad_form_ldlt() : stan::math
- trace_gen_quad_form() : stan::math
- trace_inv_quad_form_ldlt() : stan::math
- trace_quad_form() : stan::math
- transpose() : stan::math
- trigamma() : stan::math
- trunc() : stan::math
- TWO_OVER_SQRT_PI : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.